summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/knotification.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/knotification.h')
-rw-r--r--kopete/libkopete/knotification.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kopete/libkopete/knotification.h b/kopete/libkopete/knotification.h
index 1e570541..ece07bf6 100644
--- a/kopete/libkopete/knotification.h
+++ b/kopete/libkopete/knotification.h
@@ -51,9 +51,10 @@ namespace Kopete { class MetaContact; }
*
* @author Olivier Goffart <ogoffart @ kde.org>
*/
-class KOPETE_EXPORT KNotification : public QObject
+class KOPETE_EXPORT KNotification : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
enum NotificationFlags
@@ -139,7 +140,7 @@ public slots:
private:
struct Private;
Private *d;
- KNotification(TQObject *parent=0L);
+ KNotification(TQObject *tqparent=0L);
/**
* recursive function that raise the widget. @p w
*
@@ -175,9 +176,9 @@ public:
* @param pixmap is a picture which may be shown in the popup.
* @param widget is a widget where the notification reports to
* @param actions is a list of action texts.
- * @param flags is a bitmask of NotificationsFlags
+ * @param flags is a bittqmask of NotificationsFlags
*/
- static KNotification *event( const TQString& eventId , const TQString& text=TQString::null,
+ static KNotification *event( const TQString& eventId , const TQString& text=TQString(),
const TQPixmap& pixmap=TQPixmap(), TQWidget *widget=0L,
const TQStringList &actions=TQStringList(), unsigned int flags=CloseOnTimeout);
@@ -192,8 +193,8 @@ public:
* @param present The presentation method of the event
* @param level The error message level
* @param sound The sound to play if selected with @p present
* @param file The log file to append the message to if selected with @p parent
* @param commandLine the command line to run if selected with @p parent
* @param flags Indicates the way in which the notification should be handled
*/
static KNotification *userEvent( const TQString& text, const TQPixmap& pixmap,
@@ -206,7 +207,7 @@ public:
/**
* @todo find a proper way to do context-dependent notifications
*/
- static KNotification *event( Kopete::MetaContact *mc, const TQString& eventId , const TQString& text=TQString::null,
+ static KNotification *event( Kopete::MetaContact *mc, const TQString& eventId , const TQString& text=TQString(),
const TQPixmap& pixmap=TQPixmap(), TQWidget *widget=0L,
const TQStringList &actions=TQStringList(),unsigned int flags=CloseOnTimeout);
@@ -192,8 +193,8 @@ public:
* @param level The error message level
* @param sound The sound to play if selected with @p present
- * @param file The log file to append the message to if selected with @p parent
- * @param commandLine the command line to run if selected with @p parent
+ * @param file The log file to append the message to if selected with @p tqparent
+ * @param commandLine the command line to run if selected with @p tqparent
* @param flags Indicates the way in which the notification should be handled
*/